@@ -73,8 +73,13 @@ class Response(NamedTuple):
     error: Optional[str] = None
 
 
+@dataclass
+class DeletedFile:
+    file_access: Literal['file_not_found']
+
 @dataclass
 class File:
+    file_access: Literal['visible']
     id: str
     url_private: str
     size: int
@@ -83,6 +88,16 @@ class File:
     title: Optional[str] = None
     mimetype: Optional[str] = None
 
+@dataclass
+class TabutuFile:
+    """
+    'un sacciu chi minchia è sta cosa.
+
+    Sacciu sulu ca slack u manna
+    """
+    id: str
+    mode: Literal['tombstone']
+
 
 class Topic(NamedTuple):
     """
@@ -295,7 +310,7 @@ class HistoryBotMessage:
     bot_id: Optional[str]
     username: str = 'bot'
     ts: float = 0
-    files: list[File] = field(default_factory=list)
+    files: list[File | DeletedFile | TabutuFile] = field(default_factory=list)
     thread_ts: Optional[str] = None
     attachments: list[dict[str, Any]] = field(default_factory=list)
 
@@ -306,7 +321,7 @@ class HistoryMessage:
     user: str
     text: str
     ts: float
-    files: list[File] = field(default_factory=list)
+    files: list[File | DeletedFile | TabutuFile] = field(default_factory=list)
     thread_ts: Optional[str] = None
 
 
@@ -469,7 +484,11 @@ class Slack:
         if time() - last_timestamp > FOUR_DAYS:
             log('Last timestamp is too old. Defaulting to 4 days.')
             last_timestamp = time() - FOUR_DAYS
-        dt = datetime.datetime.fromtimestamp(last_timestamp)
+        try:
+            dt = datetime.datetime.fromtimestamp(last_timestamp)
+        except ValueError:
+            log(f'Unable to parse timestamp {last_timestamp}')
+            return
         log(f'Last known timestamp {dt}')
 
         chats: Sequence[IM|Channel] = []
@@ -516,7 +535,7 @@ class Slack:
                             text=msg.text,
                             user=msg.user,
                             thread_ts=msg.thread_ts,
-                            files=msg.files,
+                            files=[i for i in msg.files if isinstance(i, File)],
                             ts=msg.ts,
                         ))
                     elif isinstance(msg, HistoryBotMessage):
@@ -816,7 +835,7 @@ class Slack:
         user = (await self.get_user(msg.user)).name if isinstance(msg, HistoryMessage) else 'bot'
 
         # Top message is a file
-        if msg.text == '' and msg.files:
+        if msg.text == '' and msg.files and isinstance(msg.files[0], File):
             f = msg.files[0]
             original_txt = f'{f.title} {f.mimetype} {f.url_private}'
         else:
