@@ -23,11 +23,10 @@
 
 import asyncio
 import json
-from typing import Any, Dict, List, NamedTuple, Optional
+from typing import Any, NamedTuple, Optional
 
 from typedload import load
-import websockets
-from websockets.client import connect as wsconnect
+from websockets.asyncio.client import connect as wsconnect, ClientConnection
 
 from .exceptions import *
 from .http import Request
@@ -61,7 +60,7 @@ class SlackClient:
         self._cookie = cookie
 
         # RTM configs
-        self._websocket: Optional[websockets.client.WebSocketClientProtocol] = None
+        self._websocket: Optional[ClientConnection] = None
         self._request = Request('https://slack.com/api/')
         self._wsid = 0
 
@@ -85,7 +84,7 @@ class SlackClient:
         if self._websocket and loop:
             asyncio.create_task(self._websocket.close())
 
-    async def _do(self, request: str, post_data: Dict[str, Any], timeout: float):
+    async def _do(self, request: str, post_data: dict[str, Any], timeout: float):
         """
         Perform a POST request to the Slack Web API
 
@@ -130,11 +129,11 @@ class SlackClient:
         }
         if self._cookie:
             headers['cookie'] = self._cookie
-        self._websocket = await wsconnect(r.url, close_timeout=0.2, extra_headers=headers)
+        self._websocket = await wsconnect(r.url, close_timeout=0.2, additional_headers=headers)
         return r
 
 
-    async def api_call(self, method: str, timeout: float = 0.0, **kwargs) -> Dict[str, Any]:
+    async def api_call(self, method: str, timeout: float = 0.0, **kwargs) -> dict[str, Any]:
         """
         Call the Slack Web API as documented here: https://api.slack.com/web
 
@@ -169,7 +168,7 @@ class SlackClient:
         response_json["headers"] = dict(response.headers)
         return response_json
 
-    async def rtm_read(self) -> List[Dict[str, Any]]:
+    async def rtm_read(self) -> list[dict[str, Any]]:
         assert self._websocket
         json_data: str = await self._websocket.recv()  # type: ignore
         data = []
